@@ -107,6 +107,45 @@ def test_version_compare():
     assert res
 
 
+def test_version_compare_go():
+    res = utils.version_compare("v1.1.1", "v1.1.0", "v1.1.2")
+    assert res
+    res = utils.version_compare("v1.1.3", "v1.1.0", "v1.1.2")
+    assert not res
+    res = utils.version_compare(
+        "v0.0.0-20190308221718-c2843e01d9a2", "2019-03-25", "2019-03-25"
+    )
+    assert not res
+    res = utils.version_compare("v0.0.0-20190308221718-c2843e01d9a2", "*", "2017-03-17")
+    assert not res
+    res = utils.version_compare("v0.0.0-20190308221718-c2843e01d9a2", "*", "2019-03-17")
+    assert res
+    res = utils.version_compare(
+        "v0.0.0-20180904163835-0709b304e793", "2019-03-25", "2019-03-25"
+    )
+    assert not res
+    res = utils.version_compare(
+        "v0.0.0-20180904163835-0709b304e793", "2018-09-03", "2018-09-05"
+    )
+    assert res
+    res = utils.version_compare(
+        "v0.0.0-20180904163835-0709b304e793", "2018-09-04", "2018-09-05"
+    )
+    assert res
+    res = utils.version_compare(
+        "v0.0.0-20180904163835-0709b304e793", "2018-09-05", "2018-09-05"
+    )
+    assert not res
+    res = utils.version_compare("v0.0.0-20180904163835-0709b304e793", "*", "2017-03-17")
+    assert not res
+    res = utils.version_compare("v0.0.0-20180826012351-8a410e7b638d", "*", "2018-09-25")
+    assert res
+    res = utils.version_compare("v0.0.0-20180826012351-8a410e7b638d", "*", "2018-07-12")
+    assert not res
+    res = utils.version_compare("v0.0.0-20180826012351-8a410e7b638d", "*", "2018-09-27")
+    assert res
+
+
 def test_version_parts_compare():
     res = utils.version_compare("42.2.8", "*", "9.1.22")
     assert not res
