@@ -94,8 +94,7 @@ def build_args():
 
 
 def print_results(results):
-    """Pretty print report summary
-    """
+    """Pretty print report summary"""
     table = []
     added_list = []
     headers = [
