@@ -80,8 +80,7 @@ def convert_time(time_str):
 
 
 class Vulnerability(object):
-    """Vulnerability
-    """
+    """Vulnerability"""
 
     def __init__(
         self,
@@ -124,8 +123,7 @@ class Vulnerability(object):
 
 
 class VulnerabilityDetail(object):
-    """Vulnerability detail class
-    """
+    """Vulnerability detail class"""
 
     def __init__(
         self,
@@ -202,8 +200,7 @@ class VulnerabilityDetail(object):
 
 
 class PackageIssue(object):
-    """Package issue class
-    """
+    """Package issue class"""
 
     def __init__(
         self,
@@ -253,8 +250,7 @@ class PackageIssue(object):
 
 
 class CvssV3(object):
-    """CVSS v3 representation
-    """
+    """CVSS v3 representation"""
 
     base_score: float
     exploitability_score: float
@@ -342,6 +338,9 @@ class VulnerabilityLocation(object):
             version_right = "<=" + max_affected_version_including
         if version_left and not version_right:
             version = version_left
+            # Convert >0.0.0 to *
+            if version == ">0.0.0":
+                version = "*"
         elif not version_left and version_right:
             version = version_right
         elif version_left and version_right:
@@ -367,8 +366,7 @@ class VulnerabilityLocation(object):
 
 
 class VulnerabilityOccurrence:
-    """Class to represent an occurrence of a vulnerability
-    """
+    """Class to represent an occurrence of a vulnerability"""
 
     id: str
     problem_type: str
@@ -406,8 +404,7 @@ class VulnerabilityOccurrence:
         self.effective_severity = effective_severity
 
     def to_dict(self):
-        """Convert the object to dict
-        """
+        """Convert the object to dict"""
         return {
             "id": self.id,
             "problem_type": self.problem_type,
